# Discovering SAP AI Agents
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/discovering-sap-ai-agents#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/discovering-sap-ai-agents#prerequisites)
  * [Step 1: Provision Your Cloud ALM Instance](https://help.sap.com/docs/leanix/ea/discovering-sap-ai-agents#step-1:-provision-your-cloud-alm-instance)
  * [Step 2: Generate a Service Key in Your BTP Cockpit](https://help.sap.com/docs/leanix/ea/discovering-sap-ai-agents#step-2:-generate-a-service-key-in-your-btp-cockpit)
  * [Step 3: Connect SAP LeanIX to the SAP Cloud ALM API](https://help.sap.com/docs/leanix/ea/discovering-sap-ai-agents#step-3:-connect-sap-leanix-to-the-sap-cloud-alm-api)
  * [Linking Discovered Items to Fact Sheets](https://help.sap.com/docs/leanix/ea/discovering-sap-ai-agents#linking-discovered-items-to-fact-sheets)
  * [Viewing Synchronization Logs](https://help.sap.com/docs/leanix/ea/discovering-sap-ai-agents#viewing-synchronization-logs)


Learn how to integrate SAP LeanIX with SAP Cloud ALM to automate the discovery of SAP AI agents.
